==> haskell-persistent-template-2.8.2.3-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-template
version:              2.8.2.3
visibility:           public
id:                   persistent-template-2.8.2.3-IavHiyyDSnWHpgshv6FezK
key:                  persistent-template-2.8.2.3-IavHiyyDSnWHpgshv6FezK
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.

category:             Database, Yesod
abi:                  196dcfc3c55b5798174180e90ce1ef54
exposed:              True
exposed-modules:      Database.Persist.TH
import-dirs:          /usr/lib/ghc-8.10.1/site-local/persistent-template-2.8.2.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/persistent-template-2.8.2.3
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/persistent-template-2.8.2.3

hs-libraries:         HSpersistent-template-2.8.2.3-IavHiyyDSnWHpgshv6FezK
depends:
    aeson-1.5.2.0-Dn5yhgMBsP9BMfGA2vLCmV base-4.14.0.0
    bytestring-0.10.10.0 containers-0.6.2.1
    http-api-data-0.4.1.1-Lpd9CeCdhmB7IFkyWc0yO
    monad-control-1.0.2.3-8QLeCUNxVMjGIgzM2jQ1Qj
    monad-logger-0.3.32-5xsi4GaYuz94apACR3eNc1
    path-pieces-0.2.1-IwIGWbieIS4FgGGhOeaauD
    persistent-2.10.5.2-ElujtaRYAjAD7Skk6mPL0L
    template-haskell-2.16.0.0 text-1.2.3.2
    th-lift-instances-0.1.17-781winAOiGzGPUnLxivmNp
    transformers-0.5.6.2
    unordered-containers-0.2.11.0-HkHTKJ34jxLBLVmLFyIg2F

haddock-interfaces:
    /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock

haddock-html:         /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.8.2.3-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-template
version:              2.8.2.3
visibility:           public
id:                   persistent-template-2.8.2.3-9dqTBWdiUTx6CQdFl6fmAw
key:                  persistent-template-2.8.2.3-9dqTBWdiUTx6CQdFl6fmAw
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.

category:             Database, Yesod
abi:                  a08e61e387dba1d4e2437c35a7bae8b2
exposed:              True
exposed-modules:      Database.Persist.TH
import-dirs:          /usr/lib/ghc-8.10.1/site-local/persistent-template-2.8.2.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/persistent-template-2.8.2.3
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/persistent-template-2.8.2.3

hs-libraries:         HSpersistent-template-2.8.2.3-9dqTBWdiUTx6CQdFl6fmAw
depends:
    aeson-1.5.2.0-7cPnEEpM6rgJJrGq6G7thP base-4.14.0.0
    bytestring-0.10.10.0 containers-0.6.2.1
    http-api-data-0.4.1.1-5WeUy6MRm2r3X50w3pEiij
    monad-control-1.0.2.3-IFATvKuFOhSKFDNwrLs6xW
    monad-logger-0.3.34-BMsnBbqC7Xs548XTKEidgE
    path-pieces-0.2.1-IwIGWbieIS4FgGGhOeaauD
    persistent-2.10.5.2-9BIYorPhDATE1yMmPo4ioH
    template-haskell-2.16.0.0 text-1.2.3.2
    th-lift-instances-0.1.17-7ZPSJMhYPuM1VqGUQcKTBi
    transformers-0.5.6.2
    unordered-containers-0.2.11.0-4xXgRDqRkAy1dBzEEXx9oz

haddock-interfaces:
    /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock

haddock-html:         /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
